@@ -1,5 +1,5 @@
 -- hkt.hs: hOpenPGP key tool
--- Copyright © 2013-2017  Clint Adams
+-- Copyright © 2013-2018  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -33,14 +33,14 @@ import Control.Applicative ((<$>),(<*>), pure)
 import Control.Applicative (optional, (<|>))
 import Control.Arrow ((&&&))
 import Control.Lens ((^.), _1, _2, (^..))
-import Control.Monad.Trans.Resource (runResourceT, MonadResource)
+import Control.Monad.Trans.Resource (MonadResource, MonadThrow)
 import qualified Control.Monad.Trans.State.Lazy as S
 import qualified Data.Aeson as A
 import Data.Binary (get, put)
 import Data.Binary.Put (runPut)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
-import Data.Conduit (($=),($$), Source)
+import Data.Conduit ((.|), ConduitT, runConduitRes)
 import qualified Data.Conduit.Binary as CB
 import qualified Data.Conduit.List as CL
 import Data.Conduit.OpenPGP.Filter (conduitTKFilter, FilterPredicates(RTKFilterPredicate))
@@ -85,8 +85,8 @@ import System.IO (Handle, hFlush, stderr, hSetBuffering, BufferMode(..))
 import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
 import Text.PrettyPrint.Free ((<+>), hardline, pretty, putDoc, text)
 
-grabMatchingKeysConduit :: MonadResource m => FilePath -> Bool -> Text -> Source m TK
-grabMatchingKeysConduit fp filt srch = CB.sourceFile fp $= conduitGet get $= conduitToTKsDropping $= (if filt then conduitTKFilter ufp else CL.filter matchAny)
+grabMatchingKeysConduit :: (MonadResource m, MonadThrow m) => FilePath -> Bool -> Text -> ConduitT () TK m ()
+grabMatchingKeysConduit fp filt srch = CB.sourceFile fp .| conduitGet get .| conduitToTKsDropping .| (if filt then conduitTKFilter ufp else CL.filter matchAny)
     where
         matchAny tk = either (const False) id $ fmap (keyMatchesFingerprint True tk) efp <|> fmap (keyMatchesEightOctetKeyId True tk . Right) eeok <|> return (keyMatchesUIDSubString srch tk)
         efp = parseFingerprint srch
@@ -95,10 +95,10 @@ grabMatchingKeysConduit fp filt srch = CB.sourceFile fp $= conduitGet get $= con
         parseE = either (error . ("filter parse error: " ++)) id . parseTKExp . T.unpack -- this should be more specialized
 
 grabMatchingKeys :: FilePath -> Bool -> Text -> IO [TK]
-grabMatchingKeys fp filt srch = runResourceT $ grabMatchingKeysConduit fp filt srch $$ CL.consume
+grabMatchingKeys fp filt srch = runConduitRes $ grabMatchingKeysConduit fp filt srch .| CL.consume
 
 grabMatchingKeysKeyring :: FilePath -> Bool -> Text -> IO Keyring
-grabMatchingKeysKeyring fp filt srch = runResourceT $ grabMatchingKeysConduit fp filt srch $$ sinkKeyringMap
+grabMatchingKeysKeyring fp filt srch = runConduitRes $ grabMatchingKeysConduit fp filt srch .| sinkKeyringMap
 
 data Key = Key {
     keysize :: Maybe Int
@@ -340,8 +340,8 @@ doFindPaths o = do
     cpt <- getPOSIXTime
     kr <- grabMatchingKeysKeyring (keyring o) (targetIsFilter o) (ttarget1 o)
     -- FIXME: seriously clean this up
-    keys1 <- runResourceT $ CL.sourceList (IxSet.toList kr) $= (if filt then conduitTKFilter (ufpt (ttarget2 o)) else CL.filter (matchAny (ttarget2 o))) $$ CL.consume
-    keys2 <- runResourceT $ CL.sourceList (IxSet.toList kr) $= (if filt then conduitTKFilter (ufpt (ttarget3 o)) else CL.filter (matchAny (ttarget3 o))) $$ CL.consume
+    keys1 <- runConduitRes $ CL.sourceList (IxSet.toList kr) .| (if filt then conduitTKFilter (ufpt (ttarget2 o)) else CL.filter (matchAny (ttarget2 o))) .| CL.consume
+    keys2 <- runConduitRes $ CL.sourceList (IxSet.toList kr) .| (if filt then conduitTKFilter (ufpt (ttarget3 o)) else CL.filter (matchAny (ttarget3 o))) .| CL.consume
     let ((KeyMaps k2f f2i i2f, i), ks) = (buildMaps &&& id) (rights (map (verifyTKWith (verifySigWith (verifyAgainstKeyring kr)) (Just (posixSecondsToUTCTime cpt))) (IxSet.toList kr)))
         keygraph = buildKeyGraph ((KeyMaps k2f f2i i2f, i), ks)
         keysToIs = mapMaybe (\x -> HashMap.lookup (fingerprint (x^.tkKey._1)) f2i)
