@@ -38,7 +38,6 @@ import Control.Arrow ((***))
 import Control.Error.Util (hush)
 import Control.Lens ((^.), (&), _1, _2, mapped, over)
 import Control.Monad.Trans.Except (runExceptT)
-import Control.Monad.Trans.Resource (runResourceT)
 import Control.Monad.Trans.Writer.Lazy (execWriter, tell)
 import qualified Crypto.Hash.SHA3 as SHA3
 import qualified Data.Aeson as A
@@ -47,7 +46,7 @@ import qualified Data.ByteString as B
 import qualified Data.ByteString.Char8 as BC8
 import qualified Data.ByteString.Lazy as BL
 import qualified Data.ByteString.Base16 as Base16
-import Data.Conduit (($=),($$))
+import Data.Conduit ((.|), runConduitRes)
 import qualified Data.Conduit.Binary as CB
 import Data.Conduit.Serialization.Binary (conduitGet, conduitPut)
 import qualified Data.Conduit.List as CL
@@ -382,7 +381,7 @@ cmd = hsubparser
 doLint :: LintOptions -> IO ()
 doLint o = do
     cpt <- getPOSIXTime
-    keys <- runResourceT $ CB.sourceHandle stdin $= conduitGet get $= conduitToTKsDropping $$ CL.consume
+    keys <- runConduitRes $ CB.sourceHandle stdin .| conduitGet get .| conduitToTKsDropping .| CL.consume
     output (lintOutputFormat o) cpt keys
     where
         output Pretty cpt = mapM_ (displayDoc 0.8 . prettyKeyReport cpt)
@@ -391,9 +390,9 @@ doLint o = do
 
 doCanonicalize :: IO ()
 doCanonicalize = do
-    runResourceT $ CB.sourceHandle stdin $= conduitGet get $=
-                   conduitToTKsDropping $= CL.map canonicalize $=
-                   CL.map put $= conduitPut $$ CB.sinkHandle stdout
+    runConduitRes $ CB.sourceHandle stdin .| conduitGet get .|
+                   conduitToTKsDropping .| CL.map canonicalize .|
+                   CL.map put .| conduitPut .| CB.sinkHandle stdout
     where
         canonicalize (TK k r ui ua s) = TK k
                                            (sort r)
