@@ -1,7 +1,7 @@
 {-# LANGUAGE OverloadedStrings, RecordWildCards #-}
 
 -- hot.hs: hOpenPGP Tool
--- Copyright © 2012-2016  Clint Adams
+-- Copyright © 2012-2018  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -33,11 +33,10 @@ import Control.Applicative ((<$>), (<*>), pure)
 import Control.Applicative (optional)
 import Control.Error.Util (note)
 import Control.Monad.IO.Class (MonadIO, liftIO)
-import Control.Monad.Trans.Resource (runResourceT)
 import qualified Data.Aeson as A
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
-import Data.Conduit (($=), ($$), Sink)
+import Data.Conduit ((.|), ConduitT, runConduitRes, Void)
 import Data.Conduit.Serialization.Binary (conduitGet, conduitPut)
 import qualified Data.Conduit.Binary as CB
 import qualified Data.Conduit.List as CL
@@ -75,35 +74,35 @@ data DumpOutputFormat = DumpPretty | DumpJSON | DumpYAML | DumpShow
     deriving (Bounded, Enum, Read, Show)
 
 doDump :: DumpOptions -> IO ()
-doDump DumpOptions{..} = runResourceT $ CB.sourceHandle stdin $= conduitGet (get :: Get Pkt) $$ case outputformat of
+doDump DumpOptions{..} = runConduitRes $ CB.sourceHandle stdin .| conduitGet (get :: Get Pkt) .| case outputformat of
     DumpPretty -> prettyPrinter
     DumpJSON -> jsonSink
     DumpYAML -> yamlSink
     DumpShow -> printer
 
 -- Print every input value to standard output.
-printer :: (Show a, MonadIO m) => Sink a m ()
+printer :: (Show a, MonadIO m) => ConduitT a Void m ()
 printer = CL.mapM_ (liftIO . print)
 
-prettyPrinter :: (Pretty a, MonadIO m) => Sink a m ()
+prettyPrinter :: (Pretty a, MonadIO m) => ConduitT a Void m ()
 prettyPrinter = CL.mapM_ (liftIO . hPutDoc stdout . (<> hardline) . group . pretty)
 
-jsonSink :: (A.ToJSON a, MonadIO m) => Sink a m ()
+jsonSink :: (A.ToJSON a, MonadIO m) => ConduitT a Void m ()
 jsonSink = CL.mapM_ (liftIO . BL.putStr . flip BL.snoc 0x0a . A.encode)
 
-yamlSink :: (Y.ToJSON a, MonadIO m) => Sink a m ()
+yamlSink :: (Y.ToJSON a, MonadIO m) => ConduitT a Void m ()
 yamlSink = CL.mapM_ (liftIO . B.putStr . flip B.snoc 0x0a . Y.encode)
 
 doDeArmor :: IO ()
 doDeArmor = do
-    a <- runResourceT $ CB.sourceHandle stdin $$ CL.consume
+    a <- runConduitRes $ CB.sourceHandle stdin .| CL.consume
     case AA.decode (B.concat a) of
         Left e -> hPutStrLn stderr $ "Failure to decode ASCII Armor:" ++ e
         Right msgs -> BL.putStr $ BL.concat (map (\(Armor _ _ bs) -> bs) msgs)
 
 doArmor :: ArmoringOptions -> IO ()
 doArmor ArmoringOptions{..} = do
-    m <- runResourceT $ CB.sourceHandle stdin $$ CL.consume
+    m <- runConduitRes $ CB.sourceHandle stdin .| CL.consume
     let a = Armor armortype (("Version", "hot " ++ showVersion version):maybe [] (\x -> [("Comment", x)]) comment ) (BL.fromChunks m)
     BL.putStr $ AA.encodeLazy [a]
 
@@ -119,7 +118,7 @@ armorTypeReader :: String -> Either String ArmorType
 armorTypeReader = note "unknown armor type" . flip lookup armorTypes
 
 doFilter :: FilteringOptions -> IO ()
-doFilter fo = runResourceT $ CB.sourceHandle stdin $= conduitGet (get :: Get Pkt) $= conduitPktFilter (parseExpressions fo) $= CL.map put $= conduitPut $$ CB.sinkHandle stdout
+doFilter fo = runConduitRes $ CB.sourceHandle stdin .| conduitGet (get :: Get Pkt) .| conduitPktFilter (parseExpressions fo) .| CL.map put .| conduitPut .| CB.sinkHandle stdout
 
 doP :: Parser DumpOptions
 doP = DumpOptions
